#include <stdlib.h>

#include "sylimits.h"
#include "data.h"
#include "error.h"

void
init_df(struct stream *st)
{
    fatal("df module not available");
}
void
gets_df(void)
{
    fatal("df module not available");
}
int
get_df(char *symon_buf, int maxlen, struct stream *st)
{
    fatal("df module not available");

    /* NOT REACHED */
    return 0;
}
